from manifest_edit.plugin import ManifestIteratorPlugin
from manifest_edit.context import Context
from manifest_edit import libfmp4
from schema import Schema, Or


class Plugin(ManifestIteratorPlugin):
    '''
    supplemental_property plugin.

    The purpose of this plugin is to add a supplemental property with the
    configured schemeIdUri and Value as a SupplementalProperty, in the
    position specified in the configuration file.
    '''

    _name = __name__

    _keys = ['supplementalPropertyName', 'supplementalPropertyValue']

    # This is just the specific ["how" config] for this plugin
    def schema(self):
        return Schema(
            {
                self._keys[0]: str,
                self._keys[1]: Or(str, int)
            }
        )

    def addSupplementalProperty(self, manifest, storage):
        for suppl_property_config, element in self.config(manifest, storage):
            if not type(element) == libfmp4.mpd.Period:
                suppl_property = libfmp4.mpd.Descriptor(
                    suppl_property_config[self._keys[0]],
                    suppl_property_config[self._keys[1]]
                )
                # Check if the property already exists. If it does, do
                #  nothing and log a warning
                if suppl_property not in element.supplementalProperties:
                    element.supplementalProperties.append(suppl_property)
                else:
                    Context.log_warning('The current manifest already has a '
                                        'supplemental property {}'.
                                        format(suppl_property)
                                        )
            else:
                Context.log_warning('Cannot add Supplemental Property to a '
                                    'period, only adaptation sets or '
                                    'representations')

    def mpd(self, manifest, storage):
        self.addSupplementalProperty(manifest, storage)
